@@ -34,6 +34,8 @@ _versions = {
     'check-ignore': '1.8.5',
     # git push --force-with-lease
     'force-with-lease': '1.8.5',
+    # git submodule update --recursive was introduced in 1.6.5
+    'submodule-update-recursive': '1.6.5',
     # git for-each-ref --sort=version:refname
     'version-sort': '2.7.0',
     # Qt support for QT_AUTO_SCREEN_SCALE_FACTOR and QT_SCALE_FACTOR
