@@ -17,7 +17,6 @@ from .. import utils
 from ..i18n import N_
 from ..interaction import Interaction
 from ..models import prefs
-from ..settings import Settings
 from ..widgets import defs
 from ..widgets import standard
 
@@ -35,23 +34,24 @@ def recent(context, parent):
 
 
 class BookmarksWidget(QtWidgets.QFrame):
-
     def __init__(self, context, style=BOOKMARKS, parent=None):
         QtWidgets.QFrame.__init__(self, parent)
 
+        self.context = context
         self.style = style
-        self.settings = Settings()
-        self.tree = BookmarksTreeWidget(
-            context, style, self.settings, parent=self)
+        self.tree = BookmarksTreeWidget(context, style, parent=self)
 
         self.add_button = qtutils.create_action_button(
-            tooltip=N_('Add'), icon=icons.add())
+            tooltip=N_('Add'), icon=icons.add()
+        )
 
         self.delete_button = qtutils.create_action_button(
-            tooltip=N_('Delete'), icon=icons.remove())
+            tooltip=N_('Delete'), icon=icons.remove()
+        )
 
         self.open_button = qtutils.create_action_button(
-            tooltip=N_('Open'), icon=icons.repo())
+            tooltip=N_('Open'), icon=icons.repo()
+        )
 
         self.button_group = utils.Group(self.delete_button, self.open_button)
         self.button_group.setEnabled(False)
@@ -63,9 +63,13 @@ class BookmarksWidget(QtWidgets.QFrame):
             self.setToolTip(N_('Recent repositories'))
             self.add_button.hide()
 
-        self.button_layout = qtutils.hbox(defs.no_margin, defs.spacing,
-                                          self.open_button, self.add_button,
-                                          self.delete_button)
+        self.button_layout = qtutils.hbox(
+            defs.no_margin,
+            defs.spacing,
+            self.open_button,
+            self.add_button,
+            self.delete_button,
+        )
 
         self.main_layout = qtutils.vbox(defs.no_margin, defs.spacing, self.tree)
         self.setLayout(self.main_layout)
@@ -87,7 +91,6 @@ class BookmarksWidget(QtWidgets.QFrame):
 
     def reload_bookmarks(self):
         # Called once after the GUI is initialized
-        self.settings.load()
         self.tree.refresh()
 
     def tree_item_selection_changed(self):
@@ -108,11 +111,10 @@ class BookmarksTreeWidget(standard.TreeWidget):
     default_changed = Signal()
     worktree_changed = Signal()
 
-    def __init__(self, context, style, settings, parent=None):
+    def __init__(self, context, style, parent=None):
         standard.TreeWidget.__init__(self, parent=parent)
         self.context = context
         self.style = style
-        self.settings = settings
 
         self.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
         self.setHeaderHidden(True)
@@ -122,67 +124,83 @@ class BookmarksTreeWidget(standard.TreeWidget):
         self.setEditTriggers(self.SelectedClicked)
 
         self.open_action = qtutils.add_action(
-            self, N_('Open'), self.open_repo, hotkeys.OPEN)
+            self, N_('Open'), self.open_repo, hotkeys.OPEN
+        )
 
         self.accept_action = qtutils.add_action(
-            self, N_('Accept'), self.accept_repo, *hotkeys.ACCEPT)
+            self, N_('Accept'), self.accept_repo, *hotkeys.ACCEPT
+        )
 
         self.open_new_action = qtutils.add_action(
-            self, N_('Open in New Window'), self.open_new_repo, hotkeys.NEW)
+            self, N_('Open in New Window'), self.open_new_repo, hotkeys.NEW
+        )
 
         self.set_default_repo_action = qtutils.add_action(
-            self, N_('Set Default Repository'), self.set_default_repo)
+            self, N_('Set Default Repository'), self.set_default_repo
+        )
 
         self.clear_default_repo_action = qtutils.add_action(
-            self, N_('Clear Default Repository'), self.clear_default_repo)
+            self, N_('Clear Default Repository'), self.clear_default_repo
+        )
 
         self.rename_repo_action = qtutils.add_action(
-            self, N_('Rename Repository'), self.rename_repo)
+            self, N_('Rename Repository'), self.rename_repo
+        )
 
         self.open_default_action = qtutils.add_action(
-            self, cmds.OpenDefaultApp.name(), self.open_default,
-            hotkeys.PRIMARY_ACTION)
+            self, cmds.OpenDefaultApp.name(), self.open_default, hotkeys.PRIMARY_ACTION
+        )
 
         self.launch_editor_action = qtutils.add_action(
-            self, cmds.Edit.name(), self.launch_editor, hotkeys.EDIT)
+            self, cmds.Edit.name(), self.launch_editor, hotkeys.EDIT
+        )
 
         self.launch_terminal_action = qtutils.add_action(
-            self, cmds.LaunchTerminal.name(), self.launch_terminal,
-            hotkeys.TERMINAL)
+            self, cmds.LaunchTerminal.name(), self.launch_terminal, hotkeys.TERMINAL
+        )
 
-        self.copy_action = qtutils.add_action(
-            self, N_('Copy'), self.copy, hotkeys.COPY)
+        self.copy_action = qtutils.add_action(self, N_('Copy'), self.copy, hotkeys.COPY)
 
         self.delete_action = qtutils.add_action(
-            self, N_('Delete'), self.delete_bookmark)
+            self, N_('Delete'), self.delete_bookmark
+        )
+
+        self.remove_missing_action = qtutils.add_action(
+            self, N_('Prune Missing Entries'), self.remove_missing
+        )
+        self.remove_missing_action.setToolTip(
+            N_('Remove stale entries for repositories that no longer exist')
+        )
 
         # pylint: disable=no-member
         self.itemChanged.connect(self.item_changed)
         self.itemSelectionChanged.connect(self.item_selection_changed)
         self.itemDoubleClicked.connect(self.tree_double_clicked)
 
-        self.action_group = utils.Group(self.open_action,
-                                        self.open_new_action,
-                                        self.copy_action,
-                                        self.launch_editor_action,
-                                        self.launch_terminal_action,
-                                        self.open_default_action,
-                                        self.rename_repo_action,
-                                        self.delete_action)
+        self.action_group = utils.Group(
+            self.open_action,
+            self.open_new_action,
+            self.copy_action,
+            self.launch_editor_action,
+            self.launch_terminal_action,
+            self.open_default_action,
+            self.rename_repo_action,
+            self.delete_action,
+        )
         self.action_group.setEnabled(False)
         self.set_default_repo_action.setEnabled(False)
         self.clear_default_repo_action.setEnabled(False)
 
         # Connections
         if style == RECENT_REPOS:
-            self.worktree_changed.connect(self.refresh,
-                                          type=Qt.QueuedConnection)
-            context.model.add_observer(context.model.message_worktree_changed,
-                                       self.worktree_changed.emit)
+            self.worktree_changed.connect(self.refresh, type=Qt.QueuedConnection)
+            context.model.add_observer(
+                context.model.message_worktree_changed, self.worktree_changed.emit
+            )
 
     def refresh(self):
         context = self.context
-        settings = self.settings
+        settings = context.settings
         builder = BuildItem(context)
 
         # bookmarks
@@ -190,7 +208,6 @@ class BookmarksTreeWidget(standard.TreeWidget):
             entries = settings.bookmarks
         # recent items
         elif self.style == RECENT_REPOS:
-            settings.reload_recent()
             entries = settings.recent
 
         items = [builder.get(entry['path'], entry['name']) for entry in entries]
@@ -219,20 +236,22 @@ class BookmarksTreeWidget(standard.TreeWidget):
         menu.addAction(self.rename_repo_action)
         menu.addSeparator()
         menu.addAction(self.delete_action)
+        menu.addAction(self.remove_missing_action)
         menu.exec_(self.mapToGlobal(event.pos()))
 
     def item_changed(self, item, _index):
         self.rename_entry(item, item.text(0))
 
     def rename_entry(self, item, new_name):
+        settings = self.context.settings
         if self.style == BOOKMARKS:
-            rename = self.settings.rename_bookmark
+            rename = settings.rename_bookmark
         elif self.style == RECENT_REPOS:
-            rename = self.settings.rename_recent
+            rename = settings.rename_recent
         else:
             rename = disable_rename
         if rename(item.path, item.name, new_name):
-            self.settings.save()
+            settings.save()
             item.name = new_name
         else:
             item.setText(0, item.name)
@@ -247,8 +266,7 @@ class BookmarksTreeWidget(standard.TreeWidget):
 
     def open_default(self):
         context = self.context
-        self.apply_fn(
-            lambda item: cmds.do(cmds.OpenDefaultApp, context, [item.path]))
+        self.apply_fn(lambda item: cmds.do(cmds.OpenDefaultApp, context, [item.path]))
 
     def set_default_repo(self):
         self.apply_fn(self.set_default_item)
@@ -289,8 +307,7 @@ class BookmarksTreeWidget(standard.TreeWidget):
 
     def open_new_repo(self):
         context = self.context
-        self.apply_fn(
-            lambda item: cmds.do(cmds.OpenNewRepo, context, item.path))
+        self.apply_fn(lambda item: cmds.do(cmds.OpenNewRepo, context, item.path))
 
     def launch_editor(self):
         context = self.context
@@ -298,8 +315,7 @@ class BookmarksTreeWidget(standard.TreeWidget):
 
     def launch_terminal(self):
         context = self.context
-        self.apply_fn(
-            lambda item: cmds.do(cmds.LaunchTerminal, context, item.path))
+        self.apply_fn(lambda item: cmds.do(cmds.LaunchTerminal, context, item.path))
 
     def item_selection_changed(self):
         item = self.selected_item()
@@ -327,12 +343,13 @@ class BookmarksTreeWidget(standard.TreeWidget):
         name, path = values
         normpath = utils.expandpath(path)
         if git.is_git_worktree(normpath):
-            self.settings.add_bookmark(normpath, name)
-            self.settings.save()
+            settings = self.context.settings
+            settings.load()
+            settings.add_bookmark(normpath, name)
+            settings.save()
             self.refresh()
         else:
-            Interaction.critical(
-                N_('Error'), N_('%s is not a Git repository.') % path)
+            Interaction.critical(N_('Error'), N_('%s is not a Git repository.') % path)
 
     def delete_bookmark(self):
         """Removes a bookmark from the bookmarks list"""
@@ -346,15 +363,21 @@ class BookmarksTreeWidget(standard.TreeWidget):
             cmd = cmds.RemoveRecent
         else:
             return
-        ok, _, _, _ = cmds.do(
-            cmd, context, self.settings, item.path, item.name,
-            icon=icons.discard())
+        ok, _, _, _ = cmds.do(cmd, context, item.path, item.name, icon=icons.discard())
         if ok:
             self.refresh()
 
+    def remove_missing(self):
+        """Remove missing entries from the favorites/recent file list"""
+        settings = self.context.settings
+        if self.style == BOOKMARKS:
+            settings.remove_missing_bookmarks()
+        elif self.style == RECENT_REPOS:
+            settings.remove_missing_recent()
+        self.refresh()
+
 
 class BuildItem(object):
-
     def __init__(self, context):
         self.star_icon = icons.star()
         self.folder_icon = icons.folder()
