@@ -14,10 +14,7 @@ from .toolbarcmds import COMMANDS
 from . import defs
 
 TREE_LAYOUT = {
-    'Others': [
-        'Others::LaunchEditor',
-        'Others::RevertUnstagedEdits'
-    ],
+    'Others': ['Others::LaunchEditor', 'Others::RevertUnstagedEdits'],
     'File': [
         'File::NewRepo',
         'File::OpenRepo',
@@ -39,26 +36,20 @@ TREE_LAYOUT = {
         'Actions::Merge',
         'Actions::AbortMerge',
         'Actions::UpdateSubmodules',
-        'Actions::ResetBranchHead',
-        'Actions::ResetWorktree',
         'Actions::Grep',
-        'Actions::Search'
+        'Actions::Search',
     ],
     'Commit@@verb': [
         'Commit::Stage',
         'Commit::AmendLast',
+        'Commit::UndoLastCommit',
         'Commit::StageAll',
         'Commit::UnstageAll',
         'Commit::Unstage',
         'Commit::LoadCommitMessage',
         'Commit::GetCommitMessageTemplate',
     ],
-    'Diff': [
-        'Diff::Difftool',
-        'Diff::Expression',
-        'Diff::Branches',
-        'Diff::Diffstat'
-    ],
+    'Diff': ['Diff::Difftool', 'Diff::Expression', 'Diff::Branches', 'Diff::Diffstat'],
     'Branch': [
         'Branch::Review',
         'Branch::Create',
@@ -69,18 +60,26 @@ TREE_LAYOUT = {
         'Branch::BrowseCurrent',
         'Branch::BrowseOther',
         'Branch::VisualizeCurrent',
-        'Branch::VisualizeAll'
+        'Branch::VisualizeAll',
     ],
-    'View': [
-        'View::DAG',
-        'View::FileBrowser',
-    ]
+    'Reset': [
+        'Commit::UndoLastCommit',
+        'Commit::UnstageAll',
+        'Actions::ResetSoft',
+        'Actions::ResetMixed',
+        'Actions::RestoreWorktree',
+        'Actions::ResetKeep',
+        'Actions::ResetHard',
+    ],
+    'View': ['View::DAG', 'View::FileBrowser'],
 }
 
 
 def configure(toolbar, parent=None):
     """Launches the Toolbar configure dialog"""
-    view = ToolbarView(toolbar, parent if parent else qtutils.active_window())
+    if not parent:
+        parent = qtutils.active_window()
+    view = ToolbarView(toolbar, parent)
     view.show()
     return view
 
@@ -138,19 +137,21 @@ class ToolBarState(object):
                 continue  # filter out removed toolbars
             items = [x.data() for x in toolbar.actions()]
 
-            result.append({
-                'name': toolbar.windowTitle(),
-                'area': encode_toolbar_area(toolbar_area),
-                'break': widget.toolBarBreak(toolbar),
-                'float': toolbar.isFloating(),
-                'x': toolbar.pos().x(),
-                'y': toolbar.pos().y(),
-                'width': toolbar.width(),
-                'height': toolbar.height(),
-                'show_icons': toolbar.show_icons(),
-                'visible': toolbar.isVisible(),
-                'items': items,
-                })
+            result.append(
+                {
+                    'name': toolbar.windowTitle(),
+                    'area': encode_toolbar_area(toolbar_area),
+                    'break': widget.toolBarBreak(toolbar),
+                    'float': toolbar.isFloating(),
+                    'x': toolbar.pos().x(),
+                    'y': toolbar.pos().y(),
+                    'width': toolbar.width(),
+                    'height': toolbar.height(),
+                    'show_icons': toolbar.show_icons(),
+                    'visible': toolbar.isVisible(),
+                    'items': items,
+                }
+            )
 
         return result
 
@@ -212,6 +213,10 @@ class ToolBar(QtWidgets.QToolBar):
 
             toolbar_action.setData(data)
 
+            tooltip = command.get('tooltip', None)
+            if tooltip:
+                toolbar_action.setToolTip('%s\n%s' % (title, tooltip))
+
     def delete_toolbar(self):
         self.parent().removeToolBar(self)
 
@@ -255,6 +260,7 @@ def decode_toolbar_area(string):
 
 class ToolbarView(standard.Dialog):
     """Provides the git-cola 'ToolBar' configure dialog"""
+
     SEPARATOR_TEXT = '----------------------------'
 
     def __init__(self, toolbar, parent=None):
@@ -272,42 +278,39 @@ class ToolbarView(standard.Dialog):
         self.remove_item = qtutils.create_button(N_('Remove Element'))
         checked = toolbar.show_icons()
         checkbox_text = N_('Show icon? (if available)')
-        self.show_icon = qtutils.checkbox(
-            checkbox_text, checkbox_text, checked)
+        self.show_icon = qtutils.checkbox(checkbox_text, checkbox_text, checked)
         self.apply_button = qtutils.ok_button(N_('Apply'))
         self.close_button = qtutils.close_button()
         self.close_button.setDefault(True)
 
         self.right_actions = qtutils.hbox(
-            defs.no_margin, defs.spacing,
-            self.add_separator,
-            self.remove_item)
+            defs.no_margin, defs.spacing, self.add_separator, self.remove_item
+        )
         self.name_layout = qtutils.hbox(
-            defs.no_margin, defs.spacing,
-            self.text_toolbar_name,
-            self.toolbar_name)
-        self.left_layout = qtutils.vbox(
-            defs.no_margin, defs.spacing,
-            self.left_list)
+            defs.no_margin, defs.spacing, self.text_toolbar_name, self.toolbar_name
+        )
+        self.left_layout = qtutils.vbox(defs.no_margin, defs.spacing, self.left_list)
         self.right_layout = qtutils.vbox(
-            defs.no_margin, defs.spacing,
-            self.right_list,
-            self.right_actions)
+            defs.no_margin, defs.spacing, self.right_list, self.right_actions
+        )
         self.top_layout = qtutils.hbox(
-            defs.no_margin, defs.spacing,
-            self.left_layout,
-            self.right_layout)
+            defs.no_margin, defs.spacing, self.left_layout, self.right_layout
+        )
         self.actions_layout = qtutils.hbox(
-            defs.no_margin, defs.spacing,
+            defs.no_margin,
+            defs.spacing,
             self.show_icon,
             qtutils.STRETCH,
             self.close_button,
-            self.apply_button)
+            self.apply_button,
+        )
         self.main_layout = qtutils.vbox(
-            defs.margin, defs.spacing,
+            defs.margin,
+            defs.spacing,
             self.name_layout,
             self.top_layout,
-            self.actions_layout)
+            self.actions_layout,
+        )
         self.setLayout(self.main_layout)
 
         qtutils.connect_button(self.add_separator, self.add_separator_action)
@@ -321,34 +324,36 @@ class ToolbarView(standard.Dialog):
         self.init_size(parent=parent)
 
     def load_right_items(self):
+        commands = self.toolbar.commands
         for action in self.toolbar.actions():
             data = action.data()
             if data['child'] == self.toolbar.SEPARATOR:
                 self.add_separator_action()
             else:
-                command = self.toolbar.commands[data['child']]
+                try:
+                    child_data = data['child']
+                    command = commands[child_data]
+                except KeyError:
+                    pass
                 title = command['title']
-                icon = command['icon']
-                self.right_list.add_item(title, data, icon)
+                icon = command.get('icon', None)
+                tooltip = command.get('tooltip', None)
+                self.right_list.add_item(title, tooltip, data, icon)
 
     def load_left_items(self):
-
-        # def current_children(actions):
-        #     result = []
-        #     for action in actions:
-        #         data = action.data()
-        #         if data['child'] != self.toolbar.SEPARATOR:
-        #             result.append(data['child'])
-
-        #     return result
-
+        commands = self.toolbar.commands
         for parent in self.toolbar.tree_layout:
             top = self.left_list.insert_top(parent)
-            # current_items = current_children(self.toolbar.actions())
             for item in self.toolbar.tree_layout[parent]:
-                command = self.toolbar.commands[item]
-                child = create_child(parent, item,
-                                     command['title'], command['icon'])
+                try:
+                    command = commands[item]
+                except KeyError:
+                    pass
+                icon = command.get('icon', None)
+                tooltip = command.get('tooltip', None)
+                child = create_child(
+                    parent, item, command['title'], tooltip, icon
+                )
                 top.appendRow(child)
 
             top.sortChildren(0, Qt.AscendingOrder)
@@ -440,14 +445,16 @@ class DraggableListWidget(QtWidgets.QListWidget):
 
         self.addItem(item)
 
-    def add_item(self, title, data, icon_text=None):
+    def add_item(self, title, tooltip, data, icon):
         item = QtWidgets.QListWidgetItem()
         item.setText(N_(title))
         item.setData(Qt.UserRole, data)
+        if tooltip:
+            item.setToolTip(tooltip)
 
-        if icon_text is not None:
-            icon = getattr(icons, icon_text, None)
-            item.setIcon(icon())
+        if icon:
+            icon_func = getattr(icons, icon)
+            item.setIcon(icon_func())
 
         self.addItem(item)
 
@@ -457,7 +464,6 @@ class DraggableListWidget(QtWidgets.QListWidget):
 
 # pylint: disable=too-many-ancestors
 class ToolbarTreeWidget(standard.TreeView):
-
     def __init__(self, parent):
         standard.TreeView.__init__(self, parent)
 
@@ -482,13 +488,14 @@ class ToolbarTreeWidget(standard.TreeView):
         return item
 
 
-def create_child(parent, child, title, icon_text=None):
+def create_child(parent, child, title, tooltip, icon):
     data = {'parent': parent, 'child': child}
     item = create_item(title, data)
-
-    if icon_text is not None:
-        icon = getattr(icons, icon_text, None)
-        item.setIcon(icon())
+    if tooltip:
+        item.setToolTip(tooltip)
+    if icon:
+        icon_func = getattr(icons, icon, None)
+        item.setIcon(icon_func())
 
     return item
 
