@@ -2,6 +2,11 @@
 import os
 import sys
 
+try:
+    import sphinx_rtd_theme
+except ImportError:
+    sphinx_rtd_theme = None
+
 # Add the cola source directory to sys.path
 abspath = os.path.abspath(os.path.realpath(__file__))
 docdir = os.path.dirname(os.path.dirname(abspath))
@@ -16,6 +21,8 @@ extensions = [
     'sphinx.ext.coverage',
     'sphinxtogithub',
 ]
+if sphinx_rtd_theme:
+    extensions.append('sphinx_rtd_theme')
 
 templates_path = ['_templates']
 source_suffix = '.rst'
@@ -23,13 +30,13 @@ source_encoding = 'utf-8'
 master_doc = 'index'
 
 project = 'git-cola'
-copyright = '2007-2017, David Aguilar and contributors'
+copyright = '2007-2020, David Aguilar and contributors'
 authors = 'David Aguilar and contributors'
 
 versionfile = os.path.join(srcdir, 'cola', '_version.py')
 scope = {}
 with open(versionfile) as f:
-    exec(f.read(), scope)
+    exec (f.read(), scope)
 
 # The short X.Y version.
 version = scope['VERSION']
@@ -39,7 +46,9 @@ release = version
 exclude_trees = ['_build']
 add_function_parentheses = True
 pygments_style = 'default'
-html_theme = 'default'
+
+if sphinx_rtd_theme:
+    html_theme = 'sphinx_rtd_theme'
 html_theme_path = ['_themes']
 html_static_path = ['_static']
 html_show_sourcelink = True
