@@ -3,6 +3,7 @@ import os
 import unittest
 
 from cola import gitcmds
+from cola.widgets.remote import get_default_remote
 
 from . import helper
 
@@ -12,13 +13,13 @@ class GitCmdsTestCase(helper.GitRepositoryTestCase):
 
     def test_currentbranch(self):
         """Test current_branch()."""
-        self.assertEqual(gitcmds.current_branch(self.context), 'master')
+        self.assertEqual(gitcmds.current_branch(self.context), 'main')
 
     def test_branch_list_local(self):
         """Test branch_list(remote=False)."""
         context = self.context
         self.commit_files()
-        expect = ['master']
+        expect = ['main']
         actual = gitcmds.branch_list(context, remote=False)
         self.assertEqual(expect, actual)
 
@@ -32,7 +33,7 @@ class GitCmdsTestCase(helper.GitRepositoryTestCase):
         self.commit_files()
         self.run_git('remote', 'add', 'origin', '.')
         self.run_git('fetch', 'origin')
-        expect = ['origin/master']
+        expect = ['origin/main']
         actual = gitcmds.branch_list(context, remote=True)
         self.assertEqual(expect, actual)
 
@@ -45,18 +46,39 @@ class GitCmdsTestCase(helper.GitRepositoryTestCase):
         """Test getting the configured upstream remote"""
         context = self.context
         self.assertEqual(gitcmds.upstream_remote(context), None)
-        self.run_git('config', 'branch.master.remote', 'test')
+        self.run_git('config', 'branch.main.remote', 'test')
         self.cfg.reset()
         self.assertEqual(gitcmds.upstream_remote(context), 'test')
 
+    def test_default_push(self):
+        """Test getting what default branch to push to"""
+        context = self.context
+
+        # no default push, no remote branch configured
+        self.assertEqual(get_default_remote(context), 'origin')
+
+        # default push set, no remote branch configured
+        self.run_git('config', 'remote.pushDefault', 'test')
+        self.cfg.reset()
+        self.assertEqual(get_default_remote(context), 'test')
+
+        # default push set, default remote branch configured
+        self.run_git('config', 'branch.main.remote', 'test2')
+        self.cfg.reset()
+        self.assertEqual(get_default_remote(context), 'test2')
+
+        # default push set, default remote branch configured, on different branch
+        self.run_git('checkout', '-b', 'other-branch')
+        self.assertEqual(get_default_remote(context), 'test')
+
     def test_tracked_branch(self):
         """Test tracked_branch()."""
         context = self.context
         self.assertEqual(gitcmds.tracked_branch(context), None)
-        self.run_git('config', 'branch.master.remote', 'test')
-        self.run_git('config', 'branch.master.merge', 'refs/heads/master')
+        self.run_git('config', 'branch.main.remote', 'test')
+        self.run_git('config', 'branch.main.merge', 'refs/heads/main')
         self.cfg.reset()
-        self.assertEqual(gitcmds.tracked_branch(context), 'test/master')
+        self.assertEqual(gitcmds.tracked_branch(context), 'test/main')
 
     def test_tracked_branch_other(self):
         """Test tracked_branch('other')."""
@@ -65,8 +87,7 @@ class GitCmdsTestCase(helper.GitRepositoryTestCase):
         self.run_git('config', 'branch.other.remote', 'test')
         self.run_git('config', 'branch.other.merge', 'refs/heads/other/branch')
         self.cfg.reset()
-        self.assertEqual(gitcmds.tracked_branch(context, 'other'),
-                         'test/other/branch')
+        self.assertEqual(gitcmds.tracked_branch(context, 'other'), 'test/other/branch')
 
     def test_untracked_files(self):
         """Test untracked_files()."""
@@ -96,14 +117,17 @@ class GitCmdsTestCase(helper.GitRepositoryTestCase):
         """Test merge_message_path()."""
         context = self.context
         self.touch('.git/SQUASH_MSG')
-        self.assertEqual(gitcmds.merge_message_path(context),
-                         os.path.abspath('.git/SQUASH_MSG'))
+        self.assertEqual(
+            gitcmds.merge_message_path(context), os.path.abspath('.git/SQUASH_MSG')
+        )
         self.touch('.git/MERGE_MSG')
-        self.assertEqual(gitcmds.merge_message_path(context),
-                         os.path.abspath('.git/MERGE_MSG'))
+        self.assertEqual(
+            gitcmds.merge_message_path(context), os.path.abspath('.git/MERGE_MSG')
+        )
         os.unlink(gitcmds.merge_message_path(context))
-        self.assertEqual(gitcmds.merge_message_path(context),
-                         os.path.abspath('.git/SQUASH_MSG'))
+        self.assertEqual(
+            gitcmds.merge_message_path(context), os.path.abspath('.git/SQUASH_MSG')
+        )
         os.unlink(gitcmds.merge_message_path(context))
         self.assertEqual(gitcmds.merge_message_path(context), None)
 
@@ -118,10 +142,22 @@ class GitCmdsTestCase(helper.GitRepositoryTestCase):
         self.run_git('remote', 'add', 'origin', '.')
         self.run_git('fetch', 'origin')
         refs = gitcmds.all_refs(self.context)
-        self.assertEqual(refs,
-                         ['a', 'b', 'c', 'master',
-                          'origin/a', 'origin/b', 'origin/c', 'origin/master',
-                          'f', 'e', 'd'])
+        self.assertEqual(
+            refs,
+            [
+                'a',
+                'b',
+                'c',
+                'main',
+                'origin/a',
+                'origin/b',
+                'origin/c',
+                'origin/main',
+                'f',
+                'e',
+                'd',
+            ],
+        )
 
     def test_all_refs_split(self):
         self.commit_files()
@@ -134,9 +170,8 @@ class GitCmdsTestCase(helper.GitRepositoryTestCase):
         self.run_git('remote', 'add', 'origin', '.')
         self.run_git('fetch', 'origin')
         local, remote, tags = gitcmds.all_refs(self.context, split=True)
-        self.assertEqual(local, ['a', 'b', 'c', 'master'])
-        self.assertEqual(remote,
-                         ['origin/a', 'origin/b', 'origin/c', 'origin/master'])
+        self.assertEqual(local, ['a', 'b', 'c', 'main'])
+        self.assertEqual(remote, ['origin/a', 'origin/b', 'origin/c', 'origin/main'])
         self.assertEqual(tags, ['f', 'e', 'd'])
 
 
