@@ -25,7 +25,7 @@ class MainModelTestCase(helper.GitRepositoryTestCase):
         """Test the 'local_branches' attribute."""
         self.commit_files()
         self.model.update_status()
-        self.assertEqual(self.model.local_branches, ['master'])
+        self.assertEqual(self.model.local_branches, ['main'])
 
     def test_remote_branches(self):
         """Test the 'remote_branches' attribute."""
@@ -36,7 +36,7 @@ class MainModelTestCase(helper.GitRepositoryTestCase):
         self.run_git('remote', 'add', 'origin', '.')
         self.run_git('fetch', 'origin')
         self.model.update_status()
-        self.assertEqual(self.model.remote_branches, ['origin/master'])
+        self.assertEqual(self.model.remote_branches, ['origin/main'])
 
     def test_modified(self):
         """Test the 'modified' attribute."""
@@ -78,7 +78,6 @@ class MainModelTestCase(helper.GitRepositoryTestCase):
 
 
 class RemoteArgsTestCase(unittest.TestCase):
-
     def setUp(self):
         self.context = context = mock.Mock()
         context.git = git.create()
@@ -88,10 +87,12 @@ class RemoteArgsTestCase(unittest.TestCase):
 
     def test_remote_args_fetch(self):
         # Fetch
-        (args, kwargs) = \
-            main.remote_args(self.context, self.remote,
-                             local_branch=self.local_branch,
-                             remote_branch=self.remote_branch)
+        (args, kwargs) = main.remote_args(
+            self.context,
+            self.remote,
+            local_branch=self.local_branch,
+            remote_branch=self.remote_branch,
+        )
 
         self.assertEqual(args, [self.remote, 'remote:local'])
         self.assertTrue(kwargs['verbose'])
@@ -100,11 +101,13 @@ class RemoteArgsTestCase(unittest.TestCase):
 
     def test_remote_args_fetch_tags(self):
         # Fetch tags
-        (args, kwargs) = \
-            main.remote_args(self.context, self.remote,
-                             tags=True,
-                             local_branch=self.local_branch,
-                             remote_branch=self.remote_branch)
+        (args, kwargs) = main.remote_args(
+            self.context,
+            self.remote,
+            tags=True,
+            local_branch=self.local_branch,
+            remote_branch=self.remote_branch,
+        )
 
         self.assertEqual(args, [self.remote, 'remote:local'])
         self.assertTrue(kwargs['verbose'])
@@ -113,11 +116,13 @@ class RemoteArgsTestCase(unittest.TestCase):
 
     def test_remote_args_pull(self):
         # Pull
-        (args, kwargs) = \
-            main.remote_args(self.context, self.remote,
-                             pull=True,
-                             local_branch='',
-                             remote_branch=self.remote_branch)
+        (args, kwargs) = main.remote_args(
+            self.context,
+            self.remote,
+            pull=True,
+            local_branch='',
+            remote_branch=self.remote_branch,
+        )
 
         self.assertEqual(args, [self.remote, 'remote'])
         self.assertTrue(kwargs['verbose'])
@@ -126,12 +131,14 @@ class RemoteArgsTestCase(unittest.TestCase):
 
     def test_remote_args_pull_rebase(self):
         # Rebasing pull
-        (args, kwargs) = \
-            main.remote_args(self.context, self.remote,
-                             pull=True,
-                             rebase=True,
-                             local_branch='',
-                             remote_branch=self.remote_branch)
+        (args, kwargs) = main.remote_args(
+            self.context,
+            self.remote,
+            pull=True,
+            rebase=True,
+            local_branch='',
+            remote_branch=self.remote_branch,
+        )
 
         self.assertEqual(args, [self.remote, 'remote'])
         self.assertTrue(kwargs['verbose'])
@@ -140,10 +147,12 @@ class RemoteArgsTestCase(unittest.TestCase):
 
     def test_remote_args_push(self):
         # Push, swap local and remote
-        (args, kwargs) = \
-            main.remote_args(self.context, self.remote,
-                             local_branch=self.remote_branch,
-                             remote_branch=self.local_branch)
+        (args, kwargs) = main.remote_args(
+            self.context,
+            self.remote,
+            local_branch=self.remote_branch,
+            remote_branch=self.local_branch,
+        )
 
         self.assertEqual(args, [self.remote, 'local:remote'])
         self.assertTrue(kwargs['verbose'])
@@ -152,11 +161,13 @@ class RemoteArgsTestCase(unittest.TestCase):
 
     def test_remote_args_push_tags(self):
         # Push, swap local and remote
-        (args, kwargs) = \
-            main.remote_args(self.context, self.remote,
-                             tags=True,
-                             local_branch=self.remote_branch,
-                             remote_branch=self.local_branch)
+        (args, kwargs) = main.remote_args(
+            self.context,
+            self.remote,
+            tags=True,
+            local_branch=self.remote_branch,
+            remote_branch=self.local_branch,
+        )
 
         self.assertEqual(args, [self.remote, 'local:remote'])
         self.assertTrue(kwargs['verbose'])
@@ -164,12 +175,14 @@ class RemoteArgsTestCase(unittest.TestCase):
         self.assertFalse('rebase' in kwargs)
 
     def test_remote_args_push_same_remote_and_local(self):
-        (args, kwargs) = \
-            main.remote_args(self.context, self.remote,
-                             tags=True,
-                             local_branch=self.local_branch,
-                             remote_branch=self.local_branch,
-                             push=True)
+        (args, kwargs) = main.remote_args(
+            self.context,
+            self.remote,
+            tags=True,
+            local_branch=self.local_branch,
+            remote_branch=self.local_branch,
+            push=True,
+        )
 
         self.assertEqual(args, [self.remote, 'local'])
         self.assertTrue(kwargs['verbose'])
@@ -177,13 +190,15 @@ class RemoteArgsTestCase(unittest.TestCase):
         self.assertFalse('rebase' in kwargs)
 
     def test_remote_args_push_set_upstream(self):
-        (args, kwargs) = \
-            main.remote_args(self.context, self.remote,
-                             tags=True,
-                             local_branch=self.local_branch,
-                             remote_branch=self.local_branch,
-                             push=True,
-                             set_upstream=True)
+        (args, kwargs) = main.remote_args(
+            self.context,
+            self.remote,
+            tags=True,
+            local_branch=self.local_branch,
+            remote_branch=self.local_branch,
+            push=True,
+            set_upstream=True,
+        )
 
         self.assertEqual(args, [self.remote, 'local'])
         self.assertTrue(kwargs['verbose'])
@@ -192,24 +207,23 @@ class RemoteArgsTestCase(unittest.TestCase):
         self.assertFalse('rebase' in kwargs)
 
     def test_remote_args_rebase_only(self):
-        (_, kwargs) = \
-            main.remote_args(self.context, self.remote,
-                             pull=True,
-                             rebase=True,
-                             ff_only=True)
+        (_, kwargs) = main.remote_args(
+            self.context, self.remote, pull=True, rebase=True, ff_only=True
+        )
         self.assertTrue(kwargs['rebase'])
         self.assertFalse('ff_only' in kwargs)
 
     def test_run_remote_action(self):
-
         def passthrough(*args, **kwargs):
             return (args, kwargs)
 
-        (args, kwargs) = \
-            main.run_remote_action(self.context, passthrough,
-                                   self.remote,
-                                   local_branch=self.local_branch,
-                                   remote_branch=self.remote_branch)
+        (args, kwargs) = main.run_remote_action(
+            self.context,
+            passthrough,
+            self.remote,
+            local_branch=self.local_branch,
+            remote_branch=self.remote_branch,
+        )
 
         self.assertEqual(args, (self.remote, 'remote:local'))
         self.assertTrue(kwargs['verbose'])
