@@ -12,8 +12,9 @@ class WordWrapTestCase(unittest.TestCase):
         self.limit = None
 
     def wrap(self, text, break_on_hyphens=True):
-        return textwrap.word_wrap(text, self.tabwidth, self.limit,
-                                  break_on_hyphens=break_on_hyphens)
+        return textwrap.word_wrap(
+            text, self.tabwidth, self.limit, break_on_hyphens=break_on_hyphens
+        )
 
     def test_word_wrap(self):
         self.limit = 16
@@ -164,17 +165,11 @@ Link: This also avoids word-wrap
     def test_triplets(self):
         text = 'xx0 xx1 xx2 xx3 xx4 xx5 xx6 xx7 xx8 xx9 xxa xxb'
 
-        expect = (
-            'xx0 xx1 xx2 xx3 xx4 xx5 xx6\n'
-            'xx7 xx8 xx9 xxa xxb'
-        )
+        expect = 'xx0 xx1 xx2 xx3 xx4 xx5 xx6\n' 'xx7 xx8 xx9 xxa xxb'
         actual = textwrap.word_wrap(text, 8, 27)
         self.assertEqual(expect, actual)
 
-        expect = (
-            'xx0 xx1 xx2 xx3 xx4 xx5\n'
-            'xx6 xx7 xx8 xx9 xxa xxb'
-        )
+        expect = 'xx0 xx1 xx2 xx3 xx4 xx5\n' 'xx6 xx7 xx8 xx9 xxa xxb'
         actual = textwrap.word_wrap(text, 8, 26)
         self.assertEqual(expect, actual)
 
@@ -187,11 +182,7 @@ Link: This also avoids word-wrap
         actual = textwrap.word_wrap(text, 8, 23)
         self.assertEqual(expect, actual)
 
-        expect = (
-            'xx0 xx1 xx2 xx3 xx4\n'
-            'xx5 xx6 xx7 xx8 xx9\n'
-            'xxa xxb'
-        )
+        expect = 'xx0 xx1 xx2 xx3 xx4\n' 'xx5 xx6 xx7 xx8 xx9\n' 'xxa xxb'
         actual = textwrap.word_wrap(text, 8, 22)
         self.assertEqual(expect, actual)
 
